package jp.co.sample;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;

/**
 * Java入門 Spring動作確認クラス.
 */
@Controller
public class HomeController {
	
	@Autowired
	SampleService service;
	
	/**
	 * http://localhost:8080/sample/userでリクエストされた場合の処理
	 * @param	model	Modelクラス
	 * @return	home画面を示す文字列
	 */
	@RequestMapping(value = "/user", method = RequestMethod.GET)
	public String home(Model model) {
		
		// ユーザ名
		model.addAttribute("user1", "schoo");
		model.addAttribute("user2", "web");
		
		// home.jspに移動
		return "home";
	}
	
	/**
	 * 指定されたIDでリクエストされた場合の処理
	 * @param	model	Modelクラス
	 * @param 	id		home画面で指定されたID（@PathVariableアノテーションで取得）
	 * @return	result画面を示す文字列
	 */
	@RequestMapping(value = "/user/{id}", method = RequestMethod.GET)
	public String getUserData(Model model, @PathVariable("id") String id) {
		
		// Serviceクラスで処理
		service.setModelData(id, model);
		
		// result.jspに移動
		return "result";
	}
}